diff --git a/cylc/flow/cfgspec/globalcfg.py b/cylc/flow/cfgspec/globalcfg.py
index 84591a03dbd..46f09924fba 100644
--- a/cylc/flow/cfgspec/globalcfg.py
+++ b/cylc/flow/cfgspec/globalcfg.py
@@ -305,15 +305,15 @@
Conf('inactivity handler', VDR.V_STRING_LIST)
Conf('shutdown handler', VDR.V_STRING_LIST)
Conf('aborted handler', VDR.V_STRING_LIST)
- Conf('stalled handler', VDR.V_STRING_LIST)
- Conf('stalled timeout handler', VDR.V_STRING_LIST)
+ Conf('stall handler', VDR.V_STRING_LIST)
+ Conf('stall timeout handler', VDR.V_STRING_LIST)
Conf('timeout', VDR.V_INTERVAL)
Conf('abort on timeout', VDR.V_BOOLEAN)
Conf('inactivity', VDR.V_INTERVAL)
Conf('abort on inactivity', VDR.V_BOOLEAN)
- Conf('stalled timeout', VDR.V_INTERVAL, DurationFloat(3600))
- Conf('abort on stalled timeout', VDR.V_BOOLEAN, True)
- Conf('abort on stalled', VDR.V_BOOLEAN)
+ Conf('stall timeout', VDR.V_INTERVAL, DurationFloat(3600))
+ Conf('abort on stall timeout', VDR.V_BOOLEAN, True)
+ Conf('abort on stall', VDR.V_BOOLEAN)
with Conf('mail', desc='''
Options for email handling.
diff --git a/cylc/flow/cfgspec/workflow.py b/cylc/flow/cfgspec/workflow.py
index 5447336f57c..8b0a190ad96 100644
--- a/cylc/flow/cfgspec/workflow.py
+++ b/cylc/flow/cfgspec/workflow.py
@@ -290,20 +290,20 @@
Conf('inactivity handler', VDR.V_STRING_LIST, None)
Conf('shutdown handler', VDR.V_STRING_LIST, None)
Conf('aborted handler', VDR.V_STRING_LIST, None)
- Conf('stalled handler', VDR.V_STRING_LIST, None)
+ Conf('stall handler', VDR.V_STRING_LIST, None)
Conf('timeout', VDR.V_INTERVAL)
- Conf('stalled timeout', VDR.V_INTERVAL)
- Conf('stalled timeout handler', VDR.V_STRING_LIST, None)
+ Conf('stall timeout', VDR.V_INTERVAL)
+ Conf('stall timeout handler', VDR.V_STRING_LIST, None)
Conf('inactivity', VDR.V_INTERVAL)
Conf('abort if startup handler fails', VDR.V_BOOLEAN)
Conf('abort if shutdown handler fails', VDR.V_BOOLEAN)
Conf('abort if timeout handler fails', VDR.V_BOOLEAN)
Conf('abort if inactivity handler fails', VDR.V_BOOLEAN)
- Conf('abort if stalled handler fails', VDR.V_BOOLEAN)
- Conf('abort if stalled timeout handler fails', VDR.V_BOOLEAN)
- Conf('abort on stalled', VDR.V_BOOLEAN)
+ Conf('abort if stall handler fails', VDR.V_BOOLEAN)
+ Conf('abort if stall timeout handler fails', VDR.V_BOOLEAN)
+ Conf('abort on stall', VDR.V_BOOLEAN)
Conf('abort on timeout', VDR.V_BOOLEAN)
- Conf('abort on stalled timeout', VDR.V_BOOLEAN)
+ Conf('abort on stall timeout', VDR.V_BOOLEAN)
Conf('abort on inactivity', VDR.V_BOOLEAN)
Conf('mail events', VDR.V_STRING_LIST, None)
Conf('expected task failures', VDR.V_STRING_LIST, desc='''
@@ -1452,9 +1452,10 @@ def upg(cfg, descr):
# Workflow timeout is now measured from start of run.
# The old timeout was measured from start of stall.
for old, new in [
- ('timeout', 'stalled timeout'),
- ('abort on timeout', 'abort on stalled timeout'),
- ('timeout handler', 'stalled timeout handler')
+ ('timeout', 'stall timeout'),
+ ('abort on timeout', 'abort on stall timeout'),
+ ('timeout handler', 'stall timeout handler'),
+ ('abort on stalled', 'abort on stall'),
]:
u.deprecate(
'8.0.0',
diff --git a/tests/flakyfunctional/cylc-get-config/04-dummy-mode-output/flow.cylc b/tests/flakyfunctional/cylc-get-config/04-dummy-mode-output/flow.cylc
index 53d0b9cd5af..e8e6090a5e8 100644
--- a/tests/flakyfunctional/cylc-get-config/04-dummy-mode-output/flow.cylc
+++ b/tests/flakyfunctional/cylc-get-config/04-dummy-mode-output/flow.cylc
@@ -4,7 +4,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/flakyfunctional/cylc-poll/16-execution-time-limit/flow.cylc b/tests/flakyfunctional/cylc-poll/16-execution-time-limit/flow.cylc
index da880d353be..6f3bd294b49 100644
--- a/tests/flakyfunctional/cylc-poll/16-execution-time-limit/flow.cylc
+++ b/tests/flakyfunctional/cylc-poll/16-execution-time-limit/flow.cylc
@@ -2,7 +2,7 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
expected task failures = foo.1
[scheduling]
[[graph]]
diff --git a/tests/flakyfunctional/events/01-task/flow.cylc b/tests/flakyfunctional/events/01-task/flow.cylc
index 73c5e6f6265..2bc15e39ba3 100644
--- a/tests/flakyfunctional/events/01-task/flow.cylc
+++ b/tests/flakyfunctional/events/01-task/flow.cylc
@@ -9,7 +9,7 @@
[scheduler]
allow implicit tasks = True
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
expected task failures = bar.1, baz.1
diff --git a/tests/flakyfunctional/events/05-timeout-ref-dummy/flow.cylc b/tests/flakyfunctional/events/05-timeout-ref-dummy/flow.cylc
index 2e4ced02e18..846a58aa7cb 100644
--- a/tests/flakyfunctional/events/05-timeout-ref-dummy/flow.cylc
+++ b/tests/flakyfunctional/events/05-timeout-ref-dummy/flow.cylc
@@ -1,8 +1,8 @@
# Time out with an unhandled failure.
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1S
+ abort on stall timeout = True
+ stall timeout = PT1S
[scheduling]
[[graph]]
R1 = "foo"
diff --git a/tests/flakyfunctional/events/40-stall-despite-clock-trig.t b/tests/flakyfunctional/events/40-stall-despite-clock-trig.t
index 7b5b1b51a41..8b14de603a5 100755
--- a/tests/flakyfunctional/events/40-stall-despite-clock-trig.t
+++ b/tests/flakyfunctional/events/40-stall-despite-clock-trig.t
@@ -25,7 +25,7 @@ run_ok "${TEST_NAME_BASE}-validate" cylc validate "${WORKFLOW_NAME}"
TEST_NAME="${TEST_NAME_BASE}-run"
workflow_run_fail "${TEST_NAME}" cylc play --debug --no-detach "${WORKFLOW_NAME}"
-grep_ok "workflow stalled" "${TEST_NAME}.stderr"
+grep_ok "Workflow stalled" "${TEST_NAME}.stderr"
purge
exit
diff --git a/tests/flakyfunctional/events/40-stall-despite-clock-trig/flow.cylc b/tests/flakyfunctional/events/40-stall-despite-clock-trig/flow.cylc
index ce0c2668725..8e89bf1d6ec 100644
--- a/tests/flakyfunctional/events/40-stall-despite-clock-trig/flow.cylc
+++ b/tests/flakyfunctional/events/40-stall-despite-clock-trig/flow.cylc
@@ -7,7 +7,7 @@
UTC mode = True
cycle point format = %Y%m%d
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT5M
[scheduling]
diff --git a/tests/flakyfunctional/events/44-timeout/flow.cylc b/tests/flakyfunctional/events/44-timeout/flow.cylc
index d41f7db3730..1e4c22322c0 100644
--- a/tests/flakyfunctional/events/44-timeout/flow.cylc
+++ b/tests/flakyfunctional/events/44-timeout/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT20S
+ abort on stall timeout = True
+ stall timeout = PT20S
[scheduling]
[[graph]]
R1 = "foo => stopper"
diff --git a/tests/flakyfunctional/execution-time-limit/00-background/flow.cylc b/tests/flakyfunctional/execution-time-limit/00-background/flow.cylc
index d931d1828f6..83d8dbdf994 100644
--- a/tests/flakyfunctional/execution-time-limit/00-background/flow.cylc
+++ b/tests/flakyfunctional/execution-time-limit/00-background/flow.cylc
@@ -3,7 +3,7 @@
[scheduler]
[[events]]
abort on inactivity = True
- abort on stalled = True
+ abort on stall = True
inactivity = PT2M
expected task failures = foo.1
diff --git a/tests/flakyfunctional/hold-release/15-hold-after/flow.cylc b/tests/flakyfunctional/hold-release/15-hold-after/flow.cylc
index 67b33eb09dd..eb148fac0cb 100644
--- a/tests/flakyfunctional/hold-release/15-hold-after/flow.cylc
+++ b/tests/flakyfunctional/hold-release/15-hold-after/flow.cylc
@@ -6,7 +6,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 20140101T00
diff --git a/tests/flakyfunctional/job-submission/19-chatty/flow.cylc b/tests/flakyfunctional/job-submission/19-chatty/flow.cylc
index e638088a2e4..460cb549ab0 100644
--- a/tests/flakyfunctional/job-submission/19-chatty/flow.cylc
+++ b/tests/flakyfunctional/job-submission/19-chatty/flow.cylc
@@ -2,8 +2,8 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT20S
+ abort on stall timeout = True
+ stall timeout = PT20S
[scheduling]
[[graph]]
diff --git a/tests/flakyfunctional/restart/14-multicycle/flow.cylc b/tests/flakyfunctional/restart/14-multicycle/flow.cylc
index 5af02ea87fd..77065598e32 100644
--- a/tests/flakyfunctional/restart/14-multicycle/flow.cylc
+++ b/tests/flakyfunctional/restart/14-multicycle/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT3M
+ abort on stall timeout = True
+ stall timeout = PT3M
[scheduling]
initial cycle point = 20130923T00
final cycle point = 20130926T00
diff --git a/tests/flakyfunctional/restart/21-task-elapsed/flow.cylc b/tests/flakyfunctional/restart/21-task-elapsed/flow.cylc
index bb4068357f3..f1b7332b90d 100644
--- a/tests/flakyfunctional/restart/21-task-elapsed/flow.cylc
+++ b/tests/flakyfunctional/restart/21-task-elapsed/flow.cylc
@@ -3,7 +3,7 @@
UTC mode=True
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/flakyfunctional/restart/39-auto-restart-no-suitable-host.t b/tests/flakyfunctional/restart/39-auto-restart-no-suitable-host.t
index e02655b1173..a43bf185505 100644
--- a/tests/flakyfunctional/restart/39-auto-restart-no-suitable-host.t
+++ b/tests/flakyfunctional/restart/39-auto-restart-no-suitable-host.t
@@ -26,9 +26,9 @@ BASE_GLOBAL_CONFIG="
interval = PT5S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
"
#-------------------------------------------------------------------------------
# test that workflows will not attempt to auto stop-restart if there is no
diff --git a/tests/flakyfunctional/restart/40-auto-restart-force-stop.t b/tests/flakyfunctional/restart/40-auto-restart-force-stop.t
index 3f22b1f5c97..c0862190e64 100644
--- a/tests/flakyfunctional/restart/40-auto-restart-force-stop.t
+++ b/tests/flakyfunctional/restart/40-auto-restart-force-stop.t
@@ -26,9 +26,9 @@ BASE_GLOBAL_CONFIG="
interval = PT5S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
"
#-------------------------------------------------------------------------------
# test the force shutdown option (auto stop, no restart) in condemned hosts
diff --git a/tests/flakyfunctional/restart/46-stop-clock-time.t b/tests/flakyfunctional/restart/46-stop-clock-time.t
index a13da3d575e..57dece26e21 100644
--- a/tests/flakyfunctional/restart/46-stop-clock-time.t
+++ b/tests/flakyfunctional/restart/46-stop-clock-time.t
@@ -38,7 +38,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
i = 1..10
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P2M
[scheduling]
diff --git a/tests/functional/authentication/basic/flow.cylc b/tests/functional/authentication/basic/flow.cylc
index f272995b1b5..2bed8ff0ad0 100644
--- a/tests/functional/authentication/basic/flow.cylc
+++ b/tests/functional/authentication/basic/flow.cylc
@@ -8,8 +8,8 @@
another_metadata = 1
[scheduler]
[[events]]
- stalled timeout = PT1M
- abort on stalled timeout = True
+ stall timeout = PT1M
+ abort on stall timeout = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/functional/broadcast/05-bad-point/flow.cylc b/tests/functional/broadcast/05-bad-point/flow.cylc
index a50eaa45e2e..dea9d80e78f 100644
--- a/tests/functional/broadcast/05-bad-point/flow.cylc
+++ b/tests/functional/broadcast/05-bad-point/flow.cylc
@@ -4,8 +4,8 @@
# And see github #1415 - it did cause the scheduler to abort.
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout=PT1M
+ abort on stall timeout = True
+ stall timeout=PT1M
[scheduling]
initial cycle point = 20150808
final cycle point = 20150808
diff --git a/tests/functional/broadcast/06-bad-namespace/flow.cylc b/tests/functional/broadcast/06-bad-namespace/flow.cylc
index 24ad7435520..af4dcd7208d 100644
--- a/tests/functional/broadcast/06-bad-namespace/flow.cylc
+++ b/tests/functional/broadcast/06-bad-namespace/flow.cylc
@@ -3,8 +3,8 @@
description=Test broadcast to an undefined namespace fails.
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout=PT1M
+ abort on stall timeout = True
+ stall timeout=PT1M
[scheduling]
initial cycle point = 20150808
final cycle point = 20150808
diff --git a/tests/functional/broadcast/08-space/flow.cylc b/tests/functional/broadcast/08-space/flow.cylc
index a27c67e62f1..055b5a74b54 100644
--- a/tests/functional/broadcast/08-space/flow.cylc
+++ b/tests/functional/broadcast/08-space/flow.cylc
@@ -4,8 +4,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout=PT1M
+ abort on stall timeout = True
+ stall timeout=PT1M
[scheduling]
initial cycle point = 20200202
final cycle point = 20200202
diff --git a/tests/functional/cli/00-cycle-points/flow.cylc b/tests/functional/cli/00-cycle-points/flow.cylc
index 4653a649b2c..f20a231387a 100644
--- a/tests/functional/cli/00-cycle-points/flow.cylc
+++ b/tests/functional/cli/00-cycle-points/flow.cylc
@@ -1,8 +1,8 @@
[scheduler]
UTC mode = true
[[events]]
- abort on stalled timeout = true
- stalled timeout = PT20S
+ abort on stall timeout = true
+ stall timeout = PT20S
[scheduling]
initial cycle point = 2015-01
final cycle point = 2015-01
diff --git a/tests/functional/cli/02-now.t b/tests/functional/cli/02-now.t
index 61aeaf5e000..247ebce120e 100755
--- a/tests/functional/cli/02-now.t
+++ b/tests/functional/cli/02-now.t
@@ -24,7 +24,7 @@ set_test_number 10
init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
[[events]]
- abort on stalled = true
+ abort on stall = true
abort on inactivity = true
inactivity = PT1M
[scheduling]
diff --git a/tests/functional/clock-expire/00-basic/flow.cylc b/tests/functional/clock-expire/00-basic/flow.cylc
index 4e6427681ea..f36b24ba741 100644
--- a/tests/functional/clock-expire/00-basic/flow.cylc
+++ b/tests/functional/clock-expire/00-basic/flow.cylc
@@ -7,8 +7,8 @@ Skip a daily post-processing workflow if the 'copy' task has expired."""
cycle point format = %Y-%m-%dT%H
allow implicit tasks = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
initial cycle point = now
final cycle point = +P3D
diff --git a/tests/functional/cyclers/48-icp-cutoff.t b/tests/functional/cyclers/48-icp-cutoff.t
index 9b1dab9e737..6a15a72cebb 100755
--- a/tests/functional/cyclers/48-icp-cutoff.t
+++ b/tests/functional/cyclers/48-icp-cutoff.t
@@ -23,7 +23,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__WORKFLOW__'
[scheduler]
cycle point time zone = Z
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 20171101T0000Z
[[graph]]
diff --git a/tests/functional/cylc-cat-log/00-local/flow.cylc b/tests/functional/cylc-cat-log/00-local/flow.cylc
index 3461b975b2d..2c5fb5946ca 100644
--- a/tests/functional/cylc-cat-log/00-local/flow.cylc
+++ b/tests/functional/cylc-cat-log/00-local/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/cylc-cat-log/01-remote/flow.cylc b/tests/functional/cylc-cat-log/01-remote/flow.cylc
index 74c24b39d37..090bbbef6bc 100644
--- a/tests/functional/cylc-cat-log/01-remote/flow.cylc
+++ b/tests/functional/cylc-cat-log/01-remote/flow.cylc
@@ -1,8 +1,8 @@
#!Jinja2
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
[[graph]]
R1 = a-task
diff --git a/tests/functional/cylc-cat-log/04-local-tail/flow.cylc b/tests/functional/cylc-cat-log/04-local-tail/flow.cylc
index 8e45aad9a6f..4180e36d4cf 100644
--- a/tests/functional/cylc-cat-log/04-local-tail/flow.cylc
+++ b/tests/functional/cylc-cat-log/04-local-tail/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT2M
+ abort on stall timeout = True
+ stall timeout = PT2M
[scheduling]
[[graph]]
R1 = foo
diff --git a/tests/functional/cylc-cat-log/05-remote-tail/flow.cylc b/tests/functional/cylc-cat-log/05-remote-tail/flow.cylc
index cd7212af23a..4049d5299ce 100644
--- a/tests/functional/cylc-cat-log/05-remote-tail/flow.cylc
+++ b/tests/functional/cylc-cat-log/05-remote-tail/flow.cylc
@@ -1,8 +1,8 @@
#!Jinja2
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT2M
+ abort on stall timeout = True
+ stall timeout = PT2M
[scheduling]
[[graph]]
R1 = foo
diff --git a/tests/functional/cylc-cat-log/09-cat-running/flow.cylc b/tests/functional/cylc-cat-log/09-cat-running/flow.cylc
index 0fc8e91b58b..c15a4276f1e 100644
--- a/tests/functional/cylc-cat-log/09-cat-running/flow.cylc
+++ b/tests/functional/cylc-cat-log/09-cat-running/flow.cylc
@@ -1,7 +1,7 @@
#!Jinja2
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/cylc-cat-log/editor/flow.cylc b/tests/functional/cylc-cat-log/editor/flow.cylc
index 2074cdb85f7..c7da5810375 100644
--- a/tests/functional/cylc-cat-log/editor/flow.cylc
+++ b/tests/functional/cylc-cat-log/editor/flow.cylc
@@ -1,8 +1,8 @@
#!jinja2
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT30S
+ abort on stall timeout = True
+ stall timeout = PT30S
[scheduling]
[[graph]]
R1 = foo
diff --git a/tests/functional/cylc-cat-log/remote-simple/flow.cylc b/tests/functional/cylc-cat-log/remote-simple/flow.cylc
index a7c9f130cf3..cab0420e913 100644
--- a/tests/functional/cylc-cat-log/remote-simple/flow.cylc
+++ b/tests/functional/cylc-cat-log/remote-simple/flow.cylc
@@ -1,8 +1,8 @@
#!Jinja2
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
[[graph]]
R1 = a-task
diff --git a/tests/functional/cylc-poll/15-job-st-file-no-batch/flow.cylc b/tests/functional/cylc-poll/15-job-st-file-no-batch/flow.cylc
index ca23fbf41cc..e7dc643f8fa 100644
--- a/tests/functional/cylc-poll/15-job-st-file-no-batch/flow.cylc
+++ b/tests/functional/cylc-poll/15-job-st-file-no-batch/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[graph]]
R1 = t1
diff --git a/tests/functional/cylc-remove/00-simple/flow.cylc b/tests/functional/cylc-remove/00-simple/flow.cylc
index f5daf54cdb0..422ffca7086 100644
--- a/tests/functional/cylc-remove/00-simple/flow.cylc
+++ b/tests/functional/cylc-remove/00-simple/flow.cylc
@@ -1,8 +1,8 @@
-# Abort on stalled timeout unless we remove unhandled failed and waiting task.
+# Abort on stall timeout unless we remove unhandled failed and waiting task.
[scheduler]
[[events]]
- stalled timeout = PT20S
- abort on stalled timeout = True
+ stall timeout = PT20S
+ abort on stall timeout = True
expected task failures = b.1
[scheduling]
[[graph]]
diff --git a/tests/functional/cylc-remove/02-cycling/flow.cylc b/tests/functional/cylc-remove/02-cycling/flow.cylc
index 570d02e4d7b..2c4b307a79b 100644
--- a/tests/functional/cylc-remove/02-cycling/flow.cylc
+++ b/tests/functional/cylc-remove/02-cycling/flow.cylc
@@ -1,10 +1,10 @@
-# Abort on stalled timeout unless we successfully remove some failed and waiting tasks.
+# Abort on stall timeout unless we successfully remove some failed and waiting tasks.
[scheduler]
UTC mode = True
cycle point format = %Y
[[events]]
- stalled timeout = PT30S
- abort on stalled timeout = True
+ stall timeout = PT30S
+ abort on stall timeout = True
expected task failures = bar.2020, baz.2021
[scheduling]
initial cycle point = 2020
diff --git a/tests/functional/events/01-timeout.t b/tests/functional/events/01-timeout.t
index 3f144d53124..6d028fe3afa 100755
--- a/tests/functional/events/01-timeout.t
+++ b/tests/functional/events/01-timeout.t
@@ -28,7 +28,7 @@ run_ok "${TEST_NAME}" cylc validate "${WORKFLOW_NAME}"
TEST_NAME="${TEST_NAME_BASE}-run"
workflow_run_fail "${TEST_NAME}" cylc play --debug --no-detach "${WORKFLOW_NAME}"
grep_ok "WARNING - workflow timed out after PT6S" "${TEST_NAME}.stderr"
-grep_ok "Workflow shutting down - Abort on workflow timeout is set" \
+grep_ok 'Workflow shutting down - "abort on timeout" is set' \
"${TEST_NAME}.stderr"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/events/03-stall-timeout.t b/tests/functional/events/03-stall-timeout.t
index ddd6fed6eb4..33e204200a0 100755
--- a/tests/functional/events/03-stall-timeout.t
+++ b/tests/functional/events/03-stall-timeout.t
@@ -28,7 +28,7 @@ run_ok "${TEST_NAME}" cylc validate "${WORKFLOW_NAME}"
TEST_NAME="${TEST_NAME_BASE}-run"
workflow_run_fail "${TEST_NAME}" cylc play --debug --no-detach "${WORKFLOW_NAME}"
grep_ok "WARNING - stall timed out after PT6S" "${TEST_NAME}.stderr"
-grep_ok "Workflow shutting down - Abort on stalled timeout is set" \
+grep_ok 'Workflow shutting down - "abort on stall timeout" is set' \
"${TEST_NAME}.stderr"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/events/18-workflow-event-mail/flow.cylc b/tests/functional/events/18-workflow-event-mail/flow.cylc
index 73bf8f0c7ad..0a4cfeb72a2 100644
--- a/tests/functional/events/18-workflow-event-mail/flow.cylc
+++ b/tests/functional/events/18-workflow-event-mail/flow.cylc
@@ -10,7 +10,7 @@
mail events = startup, shutdown
{% endif %}{# not GLOBALCFG is not defined #}
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
diff --git a/tests/functional/events/23-workflow-stalled-handler.t b/tests/functional/events/23-workflow-stalled-handler.t
index 237fd3329eb..28b2c67f968 100755
--- a/tests/functional/events/23-workflow-stalled-handler.t
+++ b/tests/functional/events/23-workflow-stalled-handler.t
@@ -15,7 +15,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see .
#-------------------------------------------------------------------------------
-# Test workflow event handler, flexible interface with stalled handler
+# Test workflow event handler, flexible interface with stall handler
. "$(dirname "$0")/test_header"
set_test_number 2
reftest
diff --git a/tests/functional/events/23-workflow-stalled-handler/flow.cylc b/tests/functional/events/23-workflow-stalled-handler/flow.cylc
index cca4c962537..d17dbe3c86c 100644
--- a/tests/functional/events/23-workflow-stalled-handler/flow.cylc
+++ b/tests/functional/events/23-workflow-stalled-handler/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
UTC mode = True # Ignore DST
[[events]]
- stalled handler = cylc set-outputs %(workflow)s bar.1
+ stall handler = cylc set-outputs %(workflow)s bar.1
expected task failures = bar.1
[scheduling]
[[graph]]
diff --git a/tests/functional/events/24-abort-on-stalled.t b/tests/functional/events/24-abort-on-stalled.t
index 5d70baffe53..7a3d52f3017 100755
--- a/tests/functional/events/24-abort-on-stalled.t
+++ b/tests/functional/events/24-abort-on-stalled.t
@@ -15,7 +15,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see .
#-------------------------------------------------------------------------------
-# Test workflow event handler, abort on stalled setting
+# Test workflow event handler, abort on stall setting
. "$(dirname "$0")/test_header"
set_test_number 3
@@ -24,7 +24,7 @@ run_ok "${TEST_NAME_BASE}-validate" \
cylc validate "${WORKFLOW_NAME}"
workflow_run_fail "${TEST_NAME_BASE}-run" \
cylc play --reference-test --debug --no-detach "${WORKFLOW_NAME}"
-grep_ok "Abort on workflow stalled is set" "${TEST_NAME_BASE}-run.stderr"
+grep_ok '"abort on stall" is set' "${TEST_NAME_BASE}-run.stderr"
purge
exit
diff --git a/tests/functional/events/24-abort-on-stalled/flow.cylc b/tests/functional/events/24-abort-on-stalled/flow.cylc
index 37c74b98383..7feeb2f5059 100644
--- a/tests/functional/events/24-abort-on-stalled/flow.cylc
+++ b/tests/functional/events/24-abort-on-stalled/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
UTC mode = True # Ignore DST
[[events]]
- abort on stalled = true
+ abort on stall = true
expected task failures = bar.1
[scheduling]
[[graph]]
diff --git a/tests/functional/events/25-held-not-stalled.t b/tests/functional/events/25-held-not-stalled.t
index 46bf3b5772f..6805ff0b3dd 100755
--- a/tests/functional/events/25-held-not-stalled.t
+++ b/tests/functional/events/25-held-not-stalled.t
@@ -15,7 +15,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see .
#-------------------------------------------------------------------------------
-# Test abort on stalled does not apply to a workflow started with --hold-after
+# Test abort on stall does not apply to a workflow started with --hold-after
# See also tests/functional/pause-resume/02-paused-not-stalled.t
diff --git a/tests/functional/events/25-held-not-stalled/flow.cylc b/tests/functional/events/25-held-not-stalled/flow.cylc
index 5924a4237b0..3f9ee546057 100644
--- a/tests/functional/events/25-held-not-stalled/flow.cylc
+++ b/tests/functional/events/25-held-not-stalled/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
abort on inactivity = False
- abort on stalled = True
+ abort on stall = True
inactivity handler = cylc release --all '%(workflow)s'
inactivity = PT5S
[scheduling]
diff --git a/tests/functional/events/26-workflow-stalled-dump-prereq.t b/tests/functional/events/26-workflow-stalled-dump-prereq.t
index 0d72f0d0f30..9258a4624e1 100755
--- a/tests/functional/events/26-workflow-stalled-dump-prereq.t
+++ b/tests/functional/events/26-workflow-stalled-dump-prereq.t
@@ -26,7 +26,7 @@ run_ok "${TEST_NAME_BASE}-validate" \
workflow_run_fail "${TEST_NAME_BASE}-run" \
cylc play --reference-test --debug --no-detach "${WORKFLOW_NAME}"
-grep_ok "Abort on workflow stalled is set" "${TEST_NAME_BASE}-run.stderr"
+grep_ok '"abort on stall" is set' "${TEST_NAME_BASE}-run.stderr"
grep_ok "WARNING - Incomplete tasks:" "${TEST_NAME_BASE}-run.stderr"
diff --git a/tests/functional/events/26-workflow-stalled-dump-prereq/flow.cylc b/tests/functional/events/26-workflow-stalled-dump-prereq/flow.cylc
index 2e5c4b0d824..586dadeab61 100644
--- a/tests/functional/events/26-workflow-stalled-dump-prereq/flow.cylc
+++ b/tests/functional/events/26-workflow-stalled-dump-prereq/flow.cylc
@@ -1,12 +1,12 @@
[scheduler]
UTC mode = True # Ignore DST
[[events]]
- abort on stalled = true
+ abort on stall = true
expected task failures = bar.20100101T0000Z
[scheduling]
initial cycle point = 20100101T0000Z
[[graph]]
- # will abort on stalled with unhandled failed bar
+ # will abort on stall with unhandled failed bar
T00, T06, T12, T18 = foo[-PT6H] & bar[-PT6H] => foo => bar => qux
T12 = qux[-PT6H] => baz
[runtime]
diff --git a/tests/functional/events/27-workflow-stalled-dump-prereq-fam.t b/tests/functional/events/27-workflow-stalled-dump-prereq-fam.t
index bfb5a197cfd..c78b8836689 100755
--- a/tests/functional/events/27-workflow-stalled-dump-prereq-fam.t
+++ b/tests/functional/events/27-workflow-stalled-dump-prereq-fam.t
@@ -27,7 +27,7 @@ run_ok "${TEST_NAME_BASE}-validate" \
workflow_run_fail "${TEST_NAME_BASE}-run" \
cylc play --reference-test --debug --no-detach "${WORKFLOW_NAME}"
-grep_ok "Abort on workflow stalled is set" "${TEST_NAME_BASE}-run.stderr"
+grep_ok '"abort on stall" is set' "${TEST_NAME_BASE}-run.stderr"
grep_ok "WARNING - Incomplete tasks:" "${TEST_NAME_BASE}-run.stderr"
diff --git a/tests/functional/events/27-workflow-stalled-dump-prereq-fam/flow.cylc b/tests/functional/events/27-workflow-stalled-dump-prereq-fam/flow.cylc
index c45067238d2..15ef8fbdccb 100644
--- a/tests/functional/events/27-workflow-stalled-dump-prereq-fam/flow.cylc
+++ b/tests/functional/events/27-workflow-stalled-dump-prereq-fam/flow.cylc
@@ -2,11 +2,11 @@
UTC mode = True # Ignore DST
allow implicit tasks = True
[[events]]
- abort on stalled = true
+ abort on stall = true
expected task failures = foo.1
[scheduling]
[[graph]]
- # will abort on stalled with unhandled failed foo
+ # will abort on stall with unhandled failed foo
R1 = """foo & goo => FAM
FAM:succeed-any => bar"""
[runtime]
diff --git a/tests/functional/events/30-task-event-mail-2/flow.cylc b/tests/functional/events/30-task-event-mail-2/flow.cylc
index 87679b8a059..c8ab5ac13d5 100644
--- a/tests/functional/events/30-task-event-mail-2/flow.cylc
+++ b/tests/functional/events/30-task-event-mail-2/flow.cylc
@@ -4,8 +4,8 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT20S
+ abort on stall timeout = True
+ stall timeout = PT20S
expected task failures = t1.1, t2.1, t3.1, t4.1, t5.1
[[mail]]
footer = see: http://localhost/stuff/%(owner)s/%(workflow)s/
diff --git a/tests/functional/events/33-task-event-job-logs-retrieve-3/flow.cylc b/tests/functional/events/33-task-event-job-logs-retrieve-3/flow.cylc
index b56bb4240da..bed63ae25bf 100644
--- a/tests/functional/events/33-task-event-job-logs-retrieve-3/flow.cylc
+++ b/tests/functional/events/33-task-event-job-logs-retrieve-3/flow.cylc
@@ -4,8 +4,8 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
expected task failures = t1.1
[scheduling]
diff --git a/tests/functional/events/48-workflow-aborted.t b/tests/functional/events/48-workflow-aborted.t
index 0ab9665efad..21fd66b5834 100755
--- a/tests/functional/events/48-workflow-aborted.t
+++ b/tests/functional/events/48-workflow-aborted.t
@@ -15,7 +15,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see .
#-------------------------------------------------------------------------------
-# Test workflow event handler, abort on stalled setting
+# Test workflow event handler, abort on stall setting
. "$(dirname "$0")/test_header"
set_test_number 4
diff --git a/tests/functional/events/48-workflow-aborted/flow.cylc b/tests/functional/events/48-workflow-aborted/flow.cylc
index 1321bfaa89f..a9bc7501e49 100644
--- a/tests/functional/events/48-workflow-aborted/flow.cylc
+++ b/tests/functional/events/48-workflow-aborted/flow.cylc
@@ -5,8 +5,8 @@
[[events]]
abort on inactivity = true
inactivity = PT1M
- abort on stalled timeout = true
- stalled timeout = PT1M
+ abort on stall timeout = true
+ stall timeout = PT1M
aborted handler = echo %(event)s %(message)s >"${CYLC_WORKFLOW_RUN_DIR}/handler.out"
[scheduling]
[[graph]]
diff --git a/tests/functional/events/stall-timeout-ref/flow.cylc b/tests/functional/events/stall-timeout-ref/flow.cylc
index 2a21c5db18e..d2143f5cfe3 100644
--- a/tests/functional/events/stall-timeout-ref/flow.cylc
+++ b/tests/functional/events/stall-timeout-ref/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1S
+ abort on stall timeout = True
+ stall timeout = PT1S
expected task failures = foo.1
[scheduling]
diff --git a/tests/functional/events/stall-timeout/flow.cylc b/tests/functional/events/stall-timeout/flow.cylc
index 76c192f5064..d274bfad3ca 100644
--- a/tests/functional/events/stall-timeout/flow.cylc
+++ b/tests/functional/events/stall-timeout/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
[[events]]
- stalled timeout = PT6S
- abort on stalled timeout = True
+ stall timeout = PT6S
+ abort on stall timeout = True
[scheduling]
[[graph]]
diff --git a/tests/functional/ext-trigger/01-no-nudge/flow.cylc b/tests/functional/ext-trigger/01-no-nudge/flow.cylc
index 7e58d3d29d3..93159c4ae0b 100644
--- a/tests/functional/ext-trigger/01-no-nudge/flow.cylc
+++ b/tests/functional/ext-trigger/01-no-nudge/flow.cylc
@@ -11,8 +11,8 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT30S
+ abort on stall timeout = True
+ stall timeout = PT30S
abort on inactivity = True
inactivity = PT30S
diff --git a/tests/functional/ext-trigger/02-cycle-point/flow.cylc b/tests/functional/ext-trigger/02-cycle-point/flow.cylc
index b9c35acc47b..663286841c4 100644
--- a/tests/functional/ext-trigger/02-cycle-point/flow.cylc
+++ b/tests/functional/ext-trigger/02-cycle-point/flow.cylc
@@ -6,8 +6,8 @@ cycling workflow. The workflow will time out and abort if the ext trigger fails
[scheduler]
cycle point format = %Y
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT30S
+ abort on stall timeout = True
+ stall timeout = PT30S
[scheduling]
initial cycle point = 2020
final cycle point = 2020
diff --git a/tests/functional/hold-release/05-release.t b/tests/functional/hold-release/05-release.t
index ed3f55d6eb2..1da294f5271 100755
--- a/tests/functional/hold-release/05-release.t
+++ b/tests/functional/hold-release/05-release.t
@@ -24,8 +24,8 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
allow implicit tasks = True
[[events]]
- stalled timeout = PT1M
- abort on stalled timeout = True
+ stall timeout = PT1M
+ abort on stall timeout = True
[scheduling]
[[graph]]
R1 = "spawner & holdrelease => STUFF & TOAST & CATS & DOGS & stop"
diff --git a/tests/functional/hold-release/08-hold.t b/tests/functional/hold-release/08-hold.t
index 1e53015ae69..9cc46df88f0 100755
--- a/tests/functional/hold-release/08-hold.t
+++ b/tests/functional/hold-release/08-hold.t
@@ -24,8 +24,8 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
allow implicit tasks = True
[[events]]
- stalled timeout = PT1M
- abort on stalled timeout = True
+ stall timeout = PT1M
+ abort on stall timeout = True
[scheduling]
[[graph]]
R1 = "spawner & holdrelease => STUFF & TOAST & CATS & DOGS & stop"
diff --git a/tests/functional/hold-release/18-hold-cycle-globs/flow.cylc b/tests/functional/hold-release/18-hold-cycle-globs/flow.cylc
index 5ea216f1b35..f1a8ec31b82 100644
--- a/tests/functional/hold-release/18-hold-cycle-globs/flow.cylc
+++ b/tests/functional/hold-release/18-hold-cycle-globs/flow.cylc
@@ -1,8 +1,8 @@
[scheduler]
UTC mode = True
[[events]]
- stalled timeout = PT1M
- abort on stalled timeout = True
+ stall timeout = PT1M
+ abort on stall timeout = True
[scheduling]
initial cycle point = 1990
final cycle point = 2030
diff --git a/tests/functional/hold-release/19-no-reset-prereq-on-waiting/flow.cylc b/tests/functional/hold-release/19-no-reset-prereq-on-waiting/flow.cylc
index dd1986f9c97..a3161807c62 100644
--- a/tests/functional/hold-release/19-no-reset-prereq-on-waiting/flow.cylc
+++ b/tests/functional/hold-release/19-no-reset-prereq-on-waiting/flow.cylc
@@ -2,7 +2,7 @@
title = Test cylc hold/release remembers satisfied dependencies
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[graph]]
R1 = """
diff --git a/tests/functional/intelligent-host-selection/01-periodic-clear-badhosts.t b/tests/functional/intelligent-host-selection/01-periodic-clear-badhosts.t
index 528d1c1c4b0..060e7fd09ed 100644
--- a/tests/functional/intelligent-host-selection/01-periodic-clear-badhosts.t
+++ b/tests/functional/intelligent-host-selection/01-periodic-clear-badhosts.t
@@ -33,9 +33,9 @@ cat >>'global.cylc' <<__HERE__
[scheduler]
[[events]]
inactivity = PT5M
- stalled timeout = PT5M
+ stall timeout = PT5M
abort on inactivity = true
- abort on stalled timeout = true
+ abort on stall timeout = true
[[main loop]]
[[[reset bad hosts]]]
interval = PT1S
diff --git a/tests/functional/intelligent-host-selection/02-badhosts/flow.cylc b/tests/functional/intelligent-host-selection/02-badhosts/flow.cylc
index 77fa8a42240..105e5fb8751 100644
--- a/tests/functional/intelligent-host-selection/02-badhosts/flow.cylc
+++ b/tests/functional/intelligent-host-selection/02-badhosts/flow.cylc
@@ -10,7 +10,7 @@ Tasks
[scheduler]
[[events]]
- abort on stalled = true
+ abort on stall = true
[scheduling]
diff --git a/tests/functional/intercycle/02-integer-abs/flow.cylc b/tests/functional/intercycle/02-integer-abs/flow.cylc
index f35a510fa62..d4a239b8c6f 100644
--- a/tests/functional/intercycle/02-integer-abs/flow.cylc
+++ b/tests/functional/intercycle/02-integer-abs/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 1
cycling mode = integer
diff --git a/tests/functional/intercycle/03-datetime-abs/flow.cylc b/tests/functional/intercycle/03-datetime-abs/flow.cylc
index d5b88bee9a9..200ccdf1d2e 100644
--- a/tests/functional/intercycle/03-datetime-abs/flow.cylc
+++ b/tests/functional/intercycle/03-datetime-abs/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 20100101T0000Z
final cycle point = +P1D
diff --git a/tests/functional/intercycle/04-datetime-abs-2/flow.cylc b/tests/functional/intercycle/04-datetime-abs-2/flow.cylc
index fa318fa3799..902ce196810 100644
--- a/tests/functional/intercycle/04-datetime-abs-2/flow.cylc
+++ b/tests/functional/intercycle/04-datetime-abs-2/flow.cylc
@@ -2,7 +2,7 @@
UTC mode = True
allow implicit tasks = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 20000101T00Z
[[graph]]
diff --git a/tests/functional/intercycle/05-datetime-abs-3/flow.cylc b/tests/functional/intercycle/05-datetime-abs-3/flow.cylc
index 6a567e09ce1..e9ac22953ec 100644
--- a/tests/functional/intercycle/05-datetime-abs-3/flow.cylc
+++ b/tests/functional/intercycle/05-datetime-abs-3/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 20100101T0000Z
final cycle point = +P1D
diff --git a/tests/functional/job-file-trap/02-pipefail/flow.cylc b/tests/functional/job-file-trap/02-pipefail/flow.cylc
index a29c3661110..6747ff1756d 100644
--- a/tests/functional/job-file-trap/02-pipefail/flow.cylc
+++ b/tests/functional/job-file-trap/02-pipefail/flow.cylc
@@ -1,7 +1,7 @@
#!jinja2
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
expected task failures = t1.1, t2.1
[scheduling]
diff --git a/tests/functional/job-file-trap/03-user-trap.t b/tests/functional/job-file-trap/03-user-trap.t
index 8b111847242..dddbd4052da 100644
--- a/tests/functional/job-file-trap/03-user-trap.t
+++ b/tests/functional/job-file-trap/03-user-trap.t
@@ -24,7 +24,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__WORKFLOW__'
[cylc]
[[events]]
abort on inactivity = True
- abort on stalled = True
+ abort on stall = True
inactivity = PT1M
[scheduling]
[[graph]]
diff --git a/tests/functional/job-submission/04-submit-num/flow.cylc b/tests/functional/job-submission/04-submit-num/flow.cylc
index fa5bea9d37b..fa6508a83d8 100644
--- a/tests/functional/job-submission/04-submit-num/flow.cylc
+++ b/tests/functional/job-submission/04-submit-num/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT30S
+ abort on stall timeout = True
+ stall timeout = PT30S
[scheduling]
[[graph]]
R1 = """
diff --git a/tests/functional/job-submission/18-clean-env/flow.cylc b/tests/functional/job-submission/18-clean-env/flow.cylc
index a1d15599c50..66b04045b25 100644
--- a/tests/functional/job-submission/18-clean-env/flow.cylc
+++ b/tests/functional/job-submission/18-clean-env/flow.cylc
@@ -2,7 +2,7 @@
[[events]]
inactivity = PT30S
abort on inactivity = True
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[graph]]
R1 = foo
diff --git a/tests/functional/job-submission/19-platform_select/flow.cylc b/tests/functional/job-submission/19-platform_select/flow.cylc
index 2ab15e93e92..935582b448c 100644
--- a/tests/functional/job-submission/19-platform_select/flow.cylc
+++ b/tests/functional/job-submission/19-platform_select/flow.cylc
@@ -7,7 +7,7 @@ purpose = """
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[dependencies]]
diff --git a/tests/functional/job-submission/20-check-chunking/flow.cylc b/tests/functional/job-submission/20-check-chunking/flow.cylc
index 2217f4635df..4ec07116cd1 100644
--- a/tests/functional/job-submission/20-check-chunking/flow.cylc
+++ b/tests/functional/job-submission/20-check-chunking/flow.cylc
@@ -3,7 +3,7 @@
[scheduler]
[[events]]
abort on inactivity = True
- abort on stalled = True
+ abort on stall = True
inactivity = PT10M
[task parameters]
diff --git a/tests/functional/logging/02-duplicates/flow.cylc b/tests/functional/logging/02-duplicates/flow.cylc
index b07cf2cff20..1c1fe5f3fb2 100644
--- a/tests/functional/logging/02-duplicates/flow.cylc
+++ b/tests/functional/logging/02-duplicates/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/logging/03-roll.t b/tests/functional/logging/03-roll.t
index 4626033e7c5..75f4e520a1c 100755
--- a/tests/functional/logging/03-roll.t
+++ b/tests/functional/logging/03-roll.t
@@ -22,7 +22,7 @@ set_test_number 11
init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/functional/modes/02-dummy-message-outputs/flow.cylc b/tests/functional/modes/02-dummy-message-outputs/flow.cylc
index 9079bfa67b2..2a304dbcee8 100644
--- a/tests/functional/modes/02-dummy-message-outputs/flow.cylc
+++ b/tests/functional/modes/02-dummy-message-outputs/flow.cylc
@@ -2,7 +2,7 @@
title = A workflow that should only succeed in dummy mode.
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/offset/01-final-next/flow.cylc b/tests/functional/offset/01-final-next/flow.cylc
index 97469a6b942..eae042452a6 100644
--- a/tests/functional/offset/01-final-next/flow.cylc
+++ b/tests/functional/offset/01-final-next/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
cycle point time zone = +01
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/optional-outputs/00-stall-on-partial/flow.cylc b/tests/functional/optional-outputs/00-stall-on-partial/flow.cylc
index 2afdf5e8c3f..fbe150e1217 100644
--- a/tests/functional/optional-outputs/00-stall-on-partial/flow.cylc
+++ b/tests/functional/optional-outputs/00-stall-on-partial/flow.cylc
@@ -1,7 +1,7 @@
# Should stall at runhead limit with partially satisfied bar
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/functional/optional-outputs/01-stall-on-incomplete/flow.cylc b/tests/functional/optional-outputs/01-stall-on-incomplete/flow.cylc
index 6541faa8ed8..04da14b5bbb 100644
--- a/tests/functional/optional-outputs/01-stall-on-incomplete/flow.cylc
+++ b/tests/functional/optional-outputs/01-stall-on-incomplete/flow.cylc
@@ -1,7 +1,7 @@
# Should stall at runhead limit with incomplete foo
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/functional/optional-outputs/02-no-stall-on-optional/flow.cylc b/tests/functional/optional-outputs/02-no-stall-on-optional/flow.cylc
index 46947e1a215..534eca9e446 100644
--- a/tests/functional/optional-outputs/02-no-stall-on-optional/flow.cylc
+++ b/tests/functional/optional-outputs/02-no-stall-on-optional/flow.cylc
@@ -1,7 +1,7 @@
# Should not stall at runhead limit with incomplete foo
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/functional/pause-resume/02-paused-not-stalled.t b/tests/functional/pause-resume/02-paused-not-stalled.t
index 4e99ee64411..9d6b62cdb83 100644
--- a/tests/functional/pause-resume/02-paused-not-stalled.t
+++ b/tests/functional/pause-resume/02-paused-not-stalled.t
@@ -15,7 +15,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see .
#-------------------------------------------------------------------------------
-# Test that abort on stalled does not apply to a paused workflow
+# Test that abort on stall does not apply to a paused workflow
# See also tests/functional/events/25-held-not-stalled.t
@@ -27,7 +27,7 @@ init_workflow "${TEST_NAME_BASE}" << __FLOW__
[scheduler]
[[events]]
abort on inactivity = False
- abort on stalled = True
+ abort on stall = True
inactivity handler = cylc play '%(workflow)s'
inactivity = PT5S
[scheduling]
diff --git a/tests/functional/pause-resume/12-pause-then-retry/flow.cylc b/tests/functional/pause-resume/12-pause-then-retry/flow.cylc
index 44e9f6618d7..b7826d5c608 100644
--- a/tests/functional/pause-resume/12-pause-then-retry/flow.cylc
+++ b/tests/functional/pause-resume/12-pause-then-retry/flow.cylc
@@ -3,7 +3,7 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
diff --git a/tests/functional/pause-resume/21-client/flow.cylc b/tests/functional/pause-resume/21-client/flow.cylc
index 640d2b7bbf3..92904783a9e 100644
--- a/tests/functional/pause-resume/21-client/flow.cylc
+++ b/tests/functional/pause-resume/21-client/flow.cylc
@@ -1,7 +1,7 @@
#!jinja2
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P1M
[scheduling]
diff --git a/tests/functional/platforms/05-host-to-platform-upgrade-fail/flow.cylc b/tests/functional/platforms/05-host-to-platform-upgrade-fail/flow.cylc
index 4ab86a16ea1..27fbc0d0f24 100644
--- a/tests/functional/platforms/05-host-to-platform-upgrade-fail/flow.cylc
+++ b/tests/functional/platforms/05-host-to-platform-upgrade-fail/flow.cylc
@@ -7,7 +7,7 @@ platform: The workflow should fail as a result.
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[graph]]
diff --git a/tests/functional/pre-initial/warm-insert/flow.cylc b/tests/functional/pre-initial/warm-insert/flow.cylc
index f666813917e..f5854261089 100644
--- a/tests/functional/pre-initial/warm-insert/flow.cylc
+++ b/tests/functional/pre-initial/warm-insert/flow.cylc
@@ -4,8 +4,8 @@
[scheduler]
UTC mode = true
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT2M
+ abort on stall timeout = True
+ stall timeout = PT2M
[scheduling]
initial cycle point = 20100101T0000Z
diff --git a/tests/functional/reload/19-remote-kill/flow.cylc b/tests/functional/reload/19-remote-kill/flow.cylc
index 8786cc782cb..c8e52a0ac08 100644
--- a/tests/functional/reload/19-remote-kill/flow.cylc
+++ b/tests/functional/reload/19-remote-kill/flow.cylc
@@ -2,7 +2,7 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
expected task failures = foo.1
[scheduling]
diff --git a/tests/functional/reload/20-stop-point/flow.cylc b/tests/functional/reload/20-stop-point/flow.cylc
index ded12e1bbdb..874713fe57c 100644
--- a/tests/functional/reload/20-stop-point/flow.cylc
+++ b/tests/functional/reload/20-stop-point/flow.cylc
@@ -2,7 +2,7 @@
#
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
diff --git a/tests/functional/reload/21-submit-fail/flow.cylc b/tests/functional/reload/21-submit-fail/flow.cylc
index a6980229702..4e607e34fda 100644
--- a/tests/functional/reload/21-submit-fail/flow.cylc
+++ b/tests/functional/reload/21-submit-fail/flow.cylc
@@ -1,7 +1,7 @@
#!Jinja2
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
expected task failures = t1.1
[scheduling]
[[graph]]
diff --git a/tests/functional/reload/runahead/flow.cylc b/tests/functional/reload/runahead/flow.cylc
index 2210bda5efb..60d1d3c38c8 100644
--- a/tests/functional/reload/runahead/flow.cylc
+++ b/tests/functional/reload/runahead/flow.cylc
@@ -1,8 +1,8 @@
[scheduler]
UTC mode = True
[[events]]
- stalled timeout = PT0.2M
- abort on stalled timeout = True
+ stall timeout = PT0.2M
+ abort on stall timeout = True
[scheduling]
initial cycle point = 2010-01-01
final cycle point = 2010-01-05
diff --git a/tests/functional/remote/01-file-install.t b/tests/functional/remote/01-file-install.t
index 7afb62508cf..6e0af018ddd 100644
--- a/tests/functional/remote/01-file-install.t
+++ b/tests/functional/remote/01-file-install.t
@@ -119,7 +119,7 @@ init_workflow "${TEST_NAME}" <<__FLOW_CONFIG__
[scheduler]
install = dir1/, dir2/
[[events]]
- abort on stalled = true
+ abort on stall = true
abort on inactivity = true
[scheduling]
diff --git a/tests/functional/remote/05-remote-init/flow.cylc b/tests/functional/remote/05-remote-init/flow.cylc
index 9539ceef74d..6d3a8c36d54 100644
--- a/tests/functional/remote/05-remote-init/flow.cylc
+++ b/tests/functional/remote/05-remote-init/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = true
+ abort on stall = true
abort on inactivity = true
[scheduling]
[[graph]]
diff --git a/tests/functional/restart/00-pre-initial/flow.cylc b/tests/functional/restart/00-pre-initial/flow.cylc
index 717cdb8a553..56bf94a6576 100644
--- a/tests/functional/restart/00-pre-initial/flow.cylc
+++ b/tests/functional/restart/00-pre-initial/flow.cylc
@@ -2,7 +2,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/restart/03-retrying.t b/tests/functional/restart/03-retrying.t
index 895c58bec94..232792e44ab 100755
--- a/tests/functional/restart/03-retrying.t
+++ b/tests/functional/restart/03-retrying.t
@@ -21,7 +21,7 @@ set_test_number 5
init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/restart/04-running.t b/tests/functional/restart/04-running.t
index 5d33a41128f..512fa74b438 100755
--- a/tests/functional/restart/04-running.t
+++ b/tests/functional/restart/04-running.t
@@ -21,7 +21,7 @@ set_test_number 5
init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/restart/22-hold/flow.cylc b/tests/functional/restart/22-hold/flow.cylc
index a857a9b664d..65e7064e112 100644
--- a/tests/functional/restart/22-hold/flow.cylc
+++ b/tests/functional/restart/22-hold/flow.cylc
@@ -3,7 +3,7 @@
UTC mode=True
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P1M
[scheduling]
diff --git a/tests/functional/restart/23-hold-retry/flow.cylc b/tests/functional/restart/23-hold-retry/flow.cylc
index f5640af8c3f..b9b771bd3ea 100644
--- a/tests/functional/restart/23-hold-retry/flow.cylc
+++ b/tests/functional/restart/23-hold-retry/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P3M
[scheduling]
diff --git a/tests/functional/restart/26-remote-kill/flow.cylc b/tests/functional/restart/26-remote-kill/flow.cylc
index 97e53c71e37..d4d13887d1e 100644
--- a/tests/functional/restart/26-remote-kill/flow.cylc
+++ b/tests/functional/restart/26-remote-kill/flow.cylc
@@ -3,7 +3,7 @@
UTC mode = True
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P6M
[scheduling]
diff --git a/tests/functional/restart/30-outputs/flow.cylc b/tests/functional/restart/30-outputs/flow.cylc
index 63e8c243f55..c27f0955f74 100644
--- a/tests/functional/restart/30-outputs/flow.cylc
+++ b/tests/functional/restart/30-outputs/flow.cylc
@@ -2,7 +2,7 @@
[scheduler]
[[events]]
abort on inactivity = True
- abort on stalled = True
+ abort on stall = True
inactivity = PT1M
[scheduling]
[[graph]]
diff --git a/tests/functional/restart/33-simulation.t b/tests/functional/restart/33-simulation.t
index b289a03bbbc..70f1b877d7f 100644
--- a/tests/functional/restart/33-simulation.t
+++ b/tests/functional/restart/33-simulation.t
@@ -23,7 +23,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
initial cycle point = 2018
[[graph]]
diff --git a/tests/functional/restart/34-auto-restart-basic.t b/tests/functional/restart/34-auto-restart-basic.t
index 195bdb06a15..e200fd064d6 100644
--- a/tests/functional/restart/34-auto-restart-basic.t
+++ b/tests/functional/restart/34-auto-restart-basic.t
@@ -30,9 +30,9 @@ BASE_GLOBAL_CONFIG="
interval = PT2S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT1M
- stalled timeout = PT1M
+ stall timeout = PT1M
[scheduler]
[[run hosts]]
available = localhost, ${CYLC_TEST_HOST}"
diff --git a/tests/functional/restart/35-auto-restart-recovery.t b/tests/functional/restart/35-auto-restart-recovery.t
index 684cf083ff0..25d4938d361 100644
--- a/tests/functional/restart/35-auto-restart-recovery.t
+++ b/tests/functional/restart/35-auto-restart-recovery.t
@@ -28,9 +28,9 @@ BASE_GLOBAL_CONFIG="
interval = PT15S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
[scheduler]
[[run hosts]]
available = localhost, ${CYLC_TEST_HOST}"
diff --git a/tests/functional/restart/37-auto-restart-delay.t b/tests/functional/restart/37-auto-restart-delay.t
index 4864d0e750c..3029bc373c5 100644
--- a/tests/functional/restart/37-auto-restart-delay.t
+++ b/tests/functional/restart/37-auto-restart-delay.t
@@ -35,9 +35,9 @@ BASE_GLOBAL_CONFIG="
interval = PT5S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
"
#-------------------------------------------------------------------------------
# Test the delayed restart feature
diff --git a/tests/functional/restart/38-auto-restart-stopping.t b/tests/functional/restart/38-auto-restart-stopping.t
index 5cc0c63034c..3f734a7d6f8 100644
--- a/tests/functional/restart/38-auto-restart-stopping.t
+++ b/tests/functional/restart/38-auto-restart-stopping.t
@@ -29,9 +29,9 @@ BASE_GLOBAL_CONFIG="
interval = PT1S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT1M
- stalled timeout = PT1M
+ stall timeout = PT1M
[[run hosts]]
available = localhost, ${CYLC_TEST_HOST}"
diff --git a/tests/functional/restart/41-auto-restart-local-jobs.t b/tests/functional/restart/41-auto-restart-local-jobs.t
index 9df8b275907..91659867ada 100644
--- a/tests/functional/restart/41-auto-restart-local-jobs.t
+++ b/tests/functional/restart/41-auto-restart-local-jobs.t
@@ -31,9 +31,9 @@ BASE_GLOBAL_CONFIG="
interval = PT2S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
"
init_workflow "${TEST_NAME_BASE}" <<< '
diff --git a/tests/functional/restart/42-auto-restart-ping-pong.t b/tests/functional/restart/42-auto-restart-ping-pong.t
index 72387b52636..ff2a26f0ff9 100644
--- a/tests/functional/restart/42-auto-restart-ping-pong.t
+++ b/tests/functional/restart/42-auto-restart-ping-pong.t
@@ -30,9 +30,9 @@ BASE_GLOBAL_CONFIG='
interval = PT5S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
'
init_workflow "${TEST_NAME_BASE}" <<< '
diff --git a/tests/functional/restart/43-auto-restart-force-override-normal.t b/tests/functional/restart/43-auto-restart-force-override-normal.t
index a69eccbbf1d..bafb680cb59 100644
--- a/tests/functional/restart/43-auto-restart-force-override-normal.t
+++ b/tests/functional/restart/43-auto-restart-force-override-normal.t
@@ -30,9 +30,9 @@ BASE_GLOBAL_CONFIG='
interval = PT5S
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT2M
- stalled timeout = PT2M
+ stall timeout = PT2M
'
init_workflow "${TEST_NAME_BASE}" <<< '
diff --git a/tests/functional/restart/44-stop-point.t b/tests/functional/restart/44-stop-point.t
index 4b8fc1af81d..401fd9ed767 100644
--- a/tests/functional/restart/44-stop-point.t
+++ b/tests/functional/restart/44-stop-point.t
@@ -44,7 +44,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
UTC mode=True
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P1M
[scheduling]
diff --git a/tests/functional/restart/45-stop-task.t b/tests/functional/restart/45-stop-task.t
index 55b89e2b41a..6d125ee9151 100644
--- a/tests/functional/restart/45-stop-task.t
+++ b/tests/functional/restart/45-stop-task.t
@@ -41,7 +41,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
i = 1..8
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P1M
[scheduling]
diff --git a/tests/functional/restart/51-final-point-reload.t b/tests/functional/restart/51-final-point-reload.t
index a0f2c66a394..419c6077593 100644
--- a/tests/functional/restart/51-final-point-reload.t
+++ b/tests/functional/restart/51-final-point-reload.t
@@ -42,7 +42,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
UTC mode=True
cycle point format = %Y
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = P1M
[scheduling]
diff --git a/tests/functional/restart/53-task-prerequisites/flow.cylc b/tests/functional/restart/53-task-prerequisites/flow.cylc
index 995b6f40403..c8d42e7308d 100644
--- a/tests/functional/restart/53-task-prerequisites/flow.cylc
+++ b/tests/functional/restart/53-task-prerequisites/flow.cylc
@@ -2,7 +2,7 @@
UTC mode = True
allow implicit tasks = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
final cycle point = 5
diff --git a/tests/functional/restart/broadcast/flow.cylc b/tests/functional/restart/broadcast/flow.cylc
index f19a1e7c0e9..1765e006760 100644
--- a/tests/functional/restart/broadcast/flow.cylc
+++ b/tests/functional/restart/broadcast/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
initial cycle point = 20130923T00
final cycle point = 20130923T00
diff --git a/tests/functional/restart/deleted-logs/flow.cylc b/tests/functional/restart/deleted-logs/flow.cylc
index c9ccdd25f30..47a801d5589 100644
--- a/tests/functional/restart/deleted-logs/flow.cylc
+++ b/tests/functional/restart/deleted-logs/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT20S
+ abort on stall timeout = True
+ stall timeout = PT20S
[scheduling]
[[graph]]
R1 = one => two
diff --git a/tests/functional/restart/failed/flow.cylc b/tests/functional/restart/failed/flow.cylc
index e4c280d57a4..b9d4063de7b 100644
--- a/tests/functional/restart/failed/flow.cylc
+++ b/tests/functional/restart/failed/flow.cylc
@@ -3,7 +3,7 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/restart/submit-failed/flow.cylc b/tests/functional/restart/submit-failed/flow.cylc
index cce5760ef99..387ced841a3 100644
--- a/tests/functional/restart/submit-failed/flow.cylc
+++ b/tests/functional/restart/submit-failed/flow.cylc
@@ -6,8 +6,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT3M
+ abort on stall timeout = True
+ stall timeout = PT3M
[scheduling]
initial cycle point = 20130923T00
diff --git a/tests/functional/restart/succeeded/flow.cylc b/tests/functional/restart/succeeded/flow.cylc
index 490d3790e3d..8a160e9204b 100644
--- a/tests/functional/restart/succeeded/flow.cylc
+++ b/tests/functional/restart/succeeded/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT3M
+ abort on stall timeout = True
+ stall timeout = PT3M
[scheduling]
initial cycle point = 20130923T00
final cycle point = 20130923T00
diff --git a/tests/functional/restart/waiting/flow.cylc b/tests/functional/restart/waiting/flow.cylc
index 4f6a78748a9..8320a9e0c48 100644
--- a/tests/functional/restart/waiting/flow.cylc
+++ b/tests/functional/restart/waiting/flow.cylc
@@ -3,8 +3,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT3M
+ abort on stall timeout = True
+ stall timeout = PT3M
[scheduling]
initial cycle point = 20130923T00
final cycle point = 20130923T00
diff --git a/tests/functional/retries/03-upgrade/flow.cylc b/tests/functional/retries/03-upgrade/flow.cylc
index 65240ecf023..d01499858eb 100644
--- a/tests/functional/retries/03-upgrade/flow.cylc
+++ b/tests/functional/retries/03-upgrade/flow.cylc
@@ -1,9 +1,9 @@
[scheduler]
[[events]]
abort on inactivity = True
- abort on stalled timeout = True
+ abort on stall timeout = True
inactivity = PT1M
- stalled timeout = PT1M
+ stall timeout = PT1M
[scheduling]
[[dependencies]]
diff --git a/tests/functional/retries/execution/flow.cylc b/tests/functional/retries/execution/flow.cylc
index 58b2edd9b22..72c36ad2d50 100644
--- a/tests/functional/retries/execution/flow.cylc
+++ b/tests/functional/retries/execution/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/retries/submission/flow.cylc b/tests/functional/retries/submission/flow.cylc
index b8869b7d9c6..39a89156a67 100644
--- a/tests/functional/retries/submission/flow.cylc
+++ b/tests/functional/retries/submission/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
expected task failures = foo.1
diff --git a/tests/functional/rnd/03-check-versions.t b/tests/functional/rnd/03-check-versions.t
index 1137f79f288..8af9346f438 100644
--- a/tests/functional/rnd/03-check-versions.t
+++ b/tests/functional/rnd/03-check-versions.t
@@ -26,8 +26,8 @@ set_test_number 3
init_workflow "${TEST_NAME_BASE}" <<__FLOW__
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout=PT30S
+ abort on stall timeout = True
+ stall timeout=PT30S
[scheduling]
[[graph]]
R1 = foo
diff --git a/tests/functional/runahead/00-runahead.t b/tests/functional/runahead/00-runahead.t
index 702780c495f..b6558963fb7 100644
--- a/tests/functional/runahead/00-runahead.t
+++ b/tests/functional/runahead/00-runahead.t
@@ -34,6 +34,7 @@ run_ok "${TEST_NAME}" sqlite3 "${DB}" \
"select max(cycle) from task_states where status!='waiting'"
cmp_ok "${TEST_NAME}.stdout" <<< "4"
#-------------------------------------------------------------------------------
-grep_ok 'Workflow shutting down - Abort on workflow stalled is set' "${WORKFLOW_RUN_DIR}/log/workflow/log"
+grep_ok 'Workflow shutting down - "abort on stall" is set' \
+ "${WORKFLOW_RUN_DIR}/log/workflow/log"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/runahead/01-check-default-simple.t b/tests/functional/runahead/01-check-default-simple.t
index 1f2ab332bbb..f13ad833def 100644
--- a/tests/functional/runahead/01-check-default-simple.t
+++ b/tests/functional/runahead/01-check-default-simple.t
@@ -38,6 +38,7 @@ run_ok "${TEST_NAME}" sqlite3 "${DB}" \
cmp_ok "${TEST_NAME}.stdout" <<< "20100102T0000Z"
# i.e. should have spawned 5 cycle points from initial 01T00
#-------------------------------------------------------------------------------
-grep_ok 'Workflow shutting down - Abort on workflow stalled is set' "${WORKFLOW_RUN_DIR}/log/workflow/log"
+grep_ok 'Workflow shutting down - "abort on stall" is set' \
+ "${WORKFLOW_RUN_DIR}/log/workflow/log"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/runahead/02-check-default-complex.t b/tests/functional/runahead/02-check-default-complex.t
index a715c628d83..4316ea15129 100644
--- a/tests/functional/runahead/02-check-default-complex.t
+++ b/tests/functional/runahead/02-check-default-complex.t
@@ -35,6 +35,7 @@ run_ok "${TEST_NAME}" sqlite3 "${DB}" \
cmp_ok "${TEST_NAME}.stdout" <<< "20100101T1200Z"
# i.e. should have spawned 5 cycle points from initial T00
#-------------------------------------------------------------------------------
-grep_ok 'Workflow shutting down - Abort on workflow stalled is set' "${WORKFLOW_RUN_DIR}/log/workflow/log"
+grep_ok 'Workflow shutting down - "abort on stall" is set' \
+ "${WORKFLOW_RUN_DIR}/log/workflow/log"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/runahead/03-check-default-future.t b/tests/functional/runahead/03-check-default-future.t
index e1f690407e2..3aaa1e17fbc 100644
--- a/tests/functional/runahead/03-check-default-future.t
+++ b/tests/functional/runahead/03-check-default-future.t
@@ -37,6 +37,7 @@ run_ok "${TEST_NAME}" sqlite3 "${DB}" \
cmp_ok "${TEST_NAME}.stdout" <<< "20100101T0400Z"
# i.e. should have spawned 5 cycle points from initial T00 (wibble not spawned)
#-------------------------------------------------------------------------------
-grep_ok 'Workflow shutting down - Abort on workflow inactivity is set' "${WORKFLOW_RUN_DIR}/log/workflow/log"
+grep_ok 'Workflow shutting down - "abort on inactivity" is set' \
+ "${WORKFLOW_RUN_DIR}/log/workflow/log"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/runahead/05-check-default-future-2.t b/tests/functional/runahead/05-check-default-future-2.t
index d1fe861614d..9022bd601f7 100644
--- a/tests/functional/runahead/05-check-default-future-2.t
+++ b/tests/functional/runahead/05-check-default-future-2.t
@@ -42,6 +42,6 @@ cmp_ok "${TEST_NAME}.stdout" <<< "20100101T1000Z"
#-------------------------------------------------------------------------------
TEST_NAME=${TEST_NAME_BASE}-check-aborted
LOG="$RUN_DIR/${WORKFLOW_NAME}/log/workflow/log"
-grep_ok 'Workflow shutting down - Abort on workflow inactivity is set' "${LOG}"
+grep_ok 'Workflow shutting down - "abort on inactivity" is set' "${LOG}"
#-------------------------------------------------------------------------------
purge
diff --git a/tests/functional/runahead/07-time-limit.t b/tests/functional/runahead/07-time-limit.t
index 7ac7853304a..b93d8e96605 100644
--- a/tests/functional/runahead/07-time-limit.t
+++ b/tests/functional/runahead/07-time-limit.t
@@ -34,7 +34,8 @@ run_ok "$TEST_NAME" sqlite3 "$DB" \
"select max(cycle) from task_states where status!='waiting'"
cmp_ok "${TEST_NAME}.stdout" <<< "20200101T0400Z"
#-------------------------------------------------------------------------------
-grep_ok 'Workflow shutting down - Abort on workflow stalled is set' "${WORKFLOW_RUN_DIR}/log/workflow/log"
+grep_ok 'Workflow shutting down - "abort on stall" is set' \
+ "${WORKFLOW_RUN_DIR}/log/workflow/log"
#-------------------------------------------------------------------------------
purge
exit
diff --git a/tests/functional/runahead/default-complex/flow.cylc b/tests/functional/runahead/default-complex/flow.cylc
index 19f85a1b620..3bdd714dd23 100644
--- a/tests/functional/runahead/default-complex/flow.cylc
+++ b/tests/functional/runahead/default-complex/flow.cylc
@@ -2,9 +2,9 @@
UTC mode = True
allow implicit tasks = True
[[events]]
- abort on stalled = True
- stalled timeout = PT30S
- abort on stalled timeout = True
+ abort on stall = True
+ stall timeout = PT30S
+ abort on stall timeout = True
[scheduling]
initial cycle point = 20100101T00
final cycle point = 20100105T00
diff --git a/tests/functional/runahead/default-simple/flow.cylc b/tests/functional/runahead/default-simple/flow.cylc
index b8c6e22c760..c2bcaf1a1a8 100644
--- a/tests/functional/runahead/default-simple/flow.cylc
+++ b/tests/functional/runahead/default-simple/flow.cylc
@@ -2,9 +2,9 @@
UTC mode = True
allow implicit tasks = True
[[events]]
- abort on stalled = True
- stalled timeout = PT30S
- abort on stalled timeout = True
+ abort on stall = True
+ stall timeout = PT30S
+ abort on stall timeout = True
[scheduling]
initial cycle point = 20100101T00
final cycle point = 20100105T00
diff --git a/tests/functional/runahead/runahead/flow.cylc b/tests/functional/runahead/runahead/flow.cylc
index 2b9b8b19db5..bd0edd03a20 100644
--- a/tests/functional/runahead/runahead/flow.cylc
+++ b/tests/functional/runahead/runahead/flow.cylc
@@ -1,9 +1,9 @@
[scheduler]
allow implicit tasks = True
[[events]]
- abort on stalled = True
- stalled timeout = PT30S
- abort on stalled timeout = True
+ abort on stall = True
+ stall timeout = PT30S
+ abort on stall timeout = True
[scheduling]
cycling mode = integer
runahead limit = P4
diff --git a/tests/functional/runahead/time-limit/flow.cylc b/tests/functional/runahead/time-limit/flow.cylc
index 980a59de9f0..cf5ab75d89d 100644
--- a/tests/functional/runahead/time-limit/flow.cylc
+++ b/tests/functional/runahead/time-limit/flow.cylc
@@ -2,7 +2,7 @@
UTC mode = True
allow implicit tasks = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
runahead limit = PT4H
initial cycle point = 2020-01-01T00
diff --git a/tests/functional/shutdown/05-auto/flow.cylc b/tests/functional/shutdown/05-auto/flow.cylc
index d096e6a0952..d3377243ca0 100644
--- a/tests/functional/shutdown/05-auto/flow.cylc
+++ b/tests/functional/shutdown/05-auto/flow.cylc
@@ -2,8 +2,8 @@
[scheduler]
[[events]]
- stalled timeout = PT2M
- abort on stalled timeout = true
+ stall timeout = PT2M
+ abort on stall timeout = true
[scheduling]
initial cycle point = 2020-01-01
final cycle point = 2020-01-01
diff --git a/tests/functional/shutdown/06-kill-fail/flow.cylc b/tests/functional/shutdown/06-kill-fail/flow.cylc
index 6cc5d324a66..ebac0d546f9 100644
--- a/tests/functional/shutdown/06-kill-fail/flow.cylc
+++ b/tests/functional/shutdown/06-kill-fail/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
[[graph]]
diff --git a/tests/functional/shutdown/07-task-fail/flow.cylc b/tests/functional/shutdown/07-task-fail/flow.cylc
index cc4b933bf18..7d32ed9e100 100644
--- a/tests/functional/shutdown/07-task-fail/flow.cylc
+++ b/tests/functional/shutdown/07-task-fail/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
[[graph]]
diff --git a/tests/functional/shutdown/08-now1/flow.cylc b/tests/functional/shutdown/08-now1/flow.cylc
index 29578cfd56f..46f0794e5a4 100644
--- a/tests/functional/shutdown/08-now1/flow.cylc
+++ b/tests/functional/shutdown/08-now1/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
diff --git a/tests/functional/shutdown/09-now2/flow.cylc b/tests/functional/shutdown/09-now2/flow.cylc
index a5b029a055d..43733b225d9 100644
--- a/tests/functional/shutdown/09-now2/flow.cylc
+++ b/tests/functional/shutdown/09-now2/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT1M
diff --git a/tests/functional/shutdown/12-bad-port-file-check/flow.cylc b/tests/functional/shutdown/12-bad-port-file-check/flow.cylc
index 1eb9b46ba59..f2b8bf56f12 100644
--- a/tests/functional/shutdown/12-bad-port-file-check/flow.cylc
+++ b/tests/functional/shutdown/12-bad-port-file-check/flow.cylc
@@ -6,7 +6,7 @@
interval = PT10S
{% endif %}{# not GLOBALCFG is not defined #}
[[events]]
- abort on stalled = False
+ abort on stall = False
[scheduling]
[[graph]]
diff --git a/tests/functional/shutdown/13-no-port-file-check/flow.cylc b/tests/functional/shutdown/13-no-port-file-check/flow.cylc
index 07fd6e0bbe2..475b228e5cb 100644
--- a/tests/functional/shutdown/13-no-port-file-check/flow.cylc
+++ b/tests/functional/shutdown/13-no-port-file-check/flow.cylc
@@ -6,7 +6,7 @@
interval = PT10S
{% endif %}{# not GLOBALCFG is not defined #}
[[events]]
- abort on stalled = False
+ abort on stall = False
[scheduling]
[[graph]]
diff --git a/tests/functional/shutdown/14-no-dir-check/flow.cylc b/tests/functional/shutdown/14-no-dir-check/flow.cylc
index bbf1b800c54..d731f0241bc 100644
--- a/tests/functional/shutdown/14-no-dir-check/flow.cylc
+++ b/tests/functional/shutdown/14-no-dir-check/flow.cylc
@@ -6,9 +6,9 @@
interval = PT10S
{% endif %}{# not GLOBALCFG is not defined #}
[[events]]
- abort on stalled = False
- abort on stalled timeout = True
- stalled timeout = PT1M
+ abort on stall = False
+ abort on stall timeout = True
+ stall timeout = PT1M
[scheduling]
[[graph]]
diff --git a/tests/functional/shutdown/18-client-on-dead-workflow.t b/tests/functional/shutdown/18-client-on-dead-workflow.t
index 7889ccca2c0..ed01990f44c 100755
--- a/tests/functional/shutdown/18-client-on-dead-workflow.t
+++ b/tests/functional/shutdown/18-client-on-dead-workflow.t
@@ -22,7 +22,7 @@ set_test_number 3
init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT3M
[scheduling]
diff --git a/tests/functional/spawn-on-demand/07-abs-triggers/flow.cylc b/tests/functional/spawn-on-demand/07-abs-triggers/flow.cylc
index 078e54060f8..66a79aca8b6 100644
--- a/tests/functional/spawn-on-demand/07-abs-triggers/flow.cylc
+++ b/tests/functional/spawn-on-demand/07-abs-triggers/flow.cylc
@@ -1,6 +1,6 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
abort on inactivity = True
inactivity = PT2M
[scheduling]
diff --git a/tests/functional/spawn-on-demand/09-set-outputs/flow.cylc b/tests/functional/spawn-on-demand/09-set-outputs/flow.cylc
index 71288aefee1..e4f2d6dda1b 100644
--- a/tests/functional/spawn-on-demand/09-set-outputs/flow.cylc
+++ b/tests/functional/spawn-on-demand/09-set-outputs/flow.cylc
@@ -5,7 +5,7 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
inactivity = PT30S
abort on inactivity = True
diff --git a/tests/functional/special/clock-360/flow.cylc b/tests/functional/special/clock-360/flow.cylc
index c9315e8222f..4da2f990d4d 100644
--- a/tests/functional/special/clock-360/flow.cylc
+++ b/tests/functional/special/clock-360/flow.cylc
@@ -2,8 +2,8 @@
[scheduler]
UTC mode = True
[[events]]
- abort on stalled timeout = True
- stalled timeout = PT0.5M
+ abort on stall timeout = True
+ stall timeout = PT0.5M
[scheduling]
initial cycle point = 20130101T00
final cycle point = 20150101T00
diff --git a/tests/functional/startup/01-log-flow-config.t b/tests/functional/startup/01-log-flow-config.t
index bb37272f647..1e521200640 100644
--- a/tests/functional/startup/01-log-flow-config.t
+++ b/tests/functional/startup/01-log-flow-config.t
@@ -26,7 +26,7 @@ init_workflow "${TEST_NAME_BASE}" <<'__FLOW_CONFIG__'
description = the weather is {{WEATHER | default("bad")}}
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
[[graph]]
R1 = reloader => whatever
diff --git a/tests/functional/triggering/17-suicide-multi/flow.cylc b/tests/functional/triggering/17-suicide-multi/flow.cylc
index a700f3aa3fa..54b35f81373 100644
--- a/tests/functional/triggering/17-suicide-multi/flow.cylc
+++ b/tests/functional/triggering/17-suicide-multi/flow.cylc
@@ -1,7 +1,7 @@
[scheduler]
allow implicit tasks = True
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
diff --git a/tests/functional/triggering/19-and-suicide/flow.cylc b/tests/functional/triggering/19-and-suicide/flow.cylc
index d74f365c0f8..65876894881 100644
--- a/tests/functional/triggering/19-and-suicide/flow.cylc
+++ b/tests/functional/triggering/19-and-suicide/flow.cylc
@@ -3,7 +3,7 @@
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
expected task failures = t1.1
[scheduling]
[[graph]]
diff --git a/tests/functional/triggering/20-and-outputs-suicide/flow.cylc b/tests/functional/triggering/20-and-outputs-suicide/flow.cylc
index 1358b69d5bf..f54cd269a5b 100644
--- a/tests/functional/triggering/20-and-outputs-suicide/flow.cylc
+++ b/tests/functional/triggering/20-and-outputs-suicide/flow.cylc
@@ -1,7 +1,7 @@
# NOTE this is an explicit test of suicide triggers, not very useful under SoD?
[scheduler]
[[events]]
- abort on stalled = True
+ abort on stall = True
[scheduling]
cycling mode = integer
initial cycle point = 1
diff --git a/tests/unit/test_workflow_events.py b/tests/unit/test_workflow_events.py
index feedc95eee8..ad2db6cff50 100644
--- a/tests/unit/test_workflow_events.py
+++ b/tests/unit/test_workflow_events.py
@@ -27,11 +27,11 @@
@pytest.mark.parametrize(
'key, expected, scheduler_mail_defined',
[
- ('handlers', ['stalled'], True),
+ ('handlers', ['stall'], True),
('hotel', None, True),
('from', 'highway@mixture', True),
('abort on timeout', True, True),
- ('handlers', ['stalled'], False),
+ ('handlers', ['stall'], False),
('hotel', None, False),
('abort on timeout', True, False),
]
@@ -65,7 +65,7 @@ def test_get_events_handler(
config.cfg = {
'scheduler': {
'events': {
- 'handlers': ['stalled']
+ 'handlers': ['stall']
},
}
}
diff --git a/cylc/flow/scheduler.py b/cylc/flow/scheduler.py
index 915093445b6..f0ea485b5c3 100644
--- a/cylc/flow/scheduler.py
+++ b/cylc/flow/scheduler.py
@@ -996,13 +996,13 @@ def set_workflow_timer(self):
self.workflow_timer_active = True
def set_stalled_timer(self):
"""Set stalled timeout timer."""
timeout = self._get_events_conf(self.EVENT_STALLED_TIMEOUT)
if timeout is None:
return
self.stalled_timer_timeout = time() + timeout
LOG.info(
- "%s stalled timer starts NOW: %s",
+ "%s stall timer starts NOW: %s",
get_seconds_as_interval_string(timeout),
get_current_time_string())
self.stalled_timer_active = True
@@ -1574,14 +1574,14 @@ async def update_data_structure(self):
if self.stalled_timer_active:
self.stalled_timer_active = False
LOG.info(
- "%s stalled timer stopped NOW: %s",
+ "%s stall timer stopped: %s",
get_seconds_as_interval_string(
self._get_events_conf(self.EVENT_STALLED_TIMEOUT)),
get_current_time_string())
return has_updated
def check_workflow_timers(self):
"""Check if workflow or stalled timers have timed out."""
if (
self.workflow_timer_active
and self._get_events_conf(self.EVENT_TIMEOUT)
@@ -1597,7 +1597,7 @@ def check_workflow_timers(self):
LOG.warning(message)
self.run_event_handlers(self.EVENT_TIMEOUT, message)
if self._get_events_conf('abort on timeout'):
- raise SchedulerError('Abort on workflow timeout is set')
+ raise SchedulerError('"abort on timeout" is set')
if (
self.stalled_timer_active
and self._get_events_conf(self.EVENT_STALLED_TIMEOUT)
@@ -1612,8 +1612,8 @@ def check_workflow_timers(self):
)
LOG.warning(message)
self.run_event_handlers(self.EVENT_STALLED_TIMEOUT, message)
- if self._get_events_conf('abort on stalled timeout'):
- raise SchedulerError('Abort on stalled timeout is set')
+ if self._get_events_conf('abort on stall timeout'):
+ raise SchedulerError('"abort on stall timeout" is set')
def check_workflow_inactive(self):
"""Check if workflow is inactive or not."""
@@ -1627,7 +1627,7 @@ def check_workflow_inactive(self):
LOG.warning(message)
self.run_event_handlers(self.EVENT_INACTIVITY_TIMEOUT, message)
if self._get_events_conf('abort on inactivity'):
- raise SchedulerError('Abort on workflow inactivity is set')
+ raise SchedulerError('"abort on inactivity" is set')
def check_workflow_stalled(self):
"""Check if workflow is stalled or not."""
@@ -1638,8 +1638,8 @@ def check_workflow_stalled(self):
self.is_stalled = self.pool.is_stalled()
if self.is_stalled:
self.run_event_handlers(self.EVENT_STALLED, 'workflow stalled')
- if self._get_events_conf('abort on stalled'):
- raise SchedulerError('Abort on workflow stalled is set')
+ if self._get_events_conf('abort on stall'):
+ raise SchedulerError('"abort on stall" is set')
# Start workflow timeout timer
if self._get_events_conf(self.EVENT_STALLED_TIMEOUT):
self.set_stalled_timer()
@@ -996,13 +996,13 @@ def set_workflow_timer(self):
self.workflow_timer_active = True
def set_stalled_timer(self):
- """Set stalled timeout timer."""
+ """Set stall timeout timer."""
timeout = self._get_events_conf(self.EVENT_STALLED_TIMEOUT)
if timeout is None:
@@ -1574,14 +1574,14 @@ async def update_data_structure(self):
return has_updated
def check_workflow_timers(self):
- """Check if workflow or stalled timers have timed out."""
+ """Check if workflow or stall timers have timed out."""
if (
self.workflow_timer_active